unit graw_pgm;  {for DELPHI 2 and above ONLY}

interface

uses
  DisplayUnit, SEE, KeyCode,
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, Menus, StdCtrls;

type
  Tgraw = class(TForm)
    MainMenu1: TMainMenu;
    mCheckMail: TMenuItem;
    mExit: TMenuItem;
    eMessage: TMemo;
    lUser: TLabel;
    lServer: TLabel;
    lPass: TLabel;
    eHost: TEdit;
    eUser: TEdit;
    ePass: TEdit;
    eMsgNbr: TEdit;
    lMsgNbr: TLabel;
    procedure mExitClick(Sender: TObject);
    procedure mCheckMailClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  graw: Tgraw;
  D1, D2, D3 : Integer;
  Code : Integer;

const
  TempSize   = 128;
  BufferSize = 2000000; {2MB buffer}

implementation

{$R *.DFM}

procedure Tgraw.mExitClick(Sender: TObject);
begin
  Application.Terminate;
end;

procedure Tgraw.mCheckMailClick(Sender: TObject);
var
  Code : Integer;
  I, N : Integer;
  NbrMsg : Integer;
  MsgNbr : Integer;
  BufferPtr : PChar;
  HostPtr : PChar;
  LogPtr  : PChar;
  PassPtr : PChar;
  TempPtr : PChar;
  UserPtr : PChar;
  MsgSize : LongInt;
  Text    : String;
  FileP   : TextFile;
begin
  {do we have all necessary parameters ?}
  if Length(eHost.Text) = 0 then
    begin
      DisplayLine(graw.eMessage,'POP3 Host is missing');
      exit;
    end;
  if Length(eUser.Text) = 0 then
    begin
      DisplayLine(graw.eMessage,'User is missing');
      exit;
    end;
  if Length(ePass.Text) = 0 then
    begin
      DisplayLine(graw.eMessage,'Password is missing');
      exit;
    end;
  if Length(eMsgNbr.Text) = 0 then
    begin
      DisplayLine(graw.eMessage,'Message number is missing');
      exit;
    end;
  MsgNbr :=  StrToInt(eMsgNbr.Text);
  if MsgNbr < 1 then
    begin
      DisplayLine(graw.eMessage,'Message number is < 1');
      exit;
    end;
  {attach SEE}
  Code := seeAttach(1, SEE_KEY_CODE);
  if Code < 0 then
    begin
      Text := Format('Cannot attach SEE (error %d)',[Code]);
      DisplayLine(graw.eMessage, Text);
      exit;
    end;
  {show SEE version}
  Code := seeStatistics(0,SEE_GET_VERSION);
  D3 := $0F AND Code;  Code := Code SHR 4;
  D2 := $0F AND Code;  Code := Code SHR 4;
  D1 := $0F AND Code;
  Text := Format('SMTP/POP3 Email Engine Version %1d.%1d.%1d',
          [D1,D2,D3]);
  DisplayLine(graw.eMessage, Text);
  {define log file}
  GetMem(LogPtr,32); StrPCopy(LogPtr, 'STATUS.LOG');
  seeStringParam(0,SEE_LOG_FILE, LogPtr); FreeMem(LogPtr, 32);
  {allocate buffers}
  GetMem(HostPtr, 64); StrPCopy(HostPtr, eHost.Text);
  GetMem(UserPtr, 64); StrPCopy(UserPtr, eUser.Text);
  GetMem(PassPtr, 64); StrPCopy(PassPtr, ePass.Text);
  {connect to POP3 server}
  mCheckmail.Enabled := False;
  SCREEN.Cursor := crHourGlass;
  Code := seePop3Connect(0,HostPtr, UserPtr, PassPtr);
  {free buffers}
  FreeMem(HostPtr,64); FreeMem(UserPtr,64); FreeMem(PassPtr,64);
  {any errors ?}
  If Code < 0 then
    begin
      DisplayString(eMessage, 'seePop3Connect: ');
      DisplayError(eMessage, Code);
      mCheckmail.Enabled := True;
      SCREEN.Cursor := crDefault;
      seeClose(0);
      seeRelease;
      exit;
    end;
  {ready to check mail}
  DisplayLine(graw.eMessage,'Connected.');
  { get # messages waiting on server}
  DisplayLine(graw.eMessage,'Getting message count...');
  NbrMsg := seeGetEmailCount(0);
  if NbrMsg < 0 then
    begin
      DisplayError(graw.eMessage,NbrMsg);
      seeClose(0);
      seeRelease;
      exit;
    end;
  DisplayLine(graw.eMessage,Format('%d messages waiting.',[NbrMsg]));
  if MsgNbr > NbrMsg then
    begin
      DisplayLine(graw.eMessage,'There is no such message');
      seeClose(0);
      seeRelease;
      exit;
    end;
  {construct pointers to strings}
  GetMem(BufferPtr, BufferSize);
  GetMem(TempPtr, TempSize);
  {read the message}
  MsgSize := seeGetEmailSize(0,MsgNbr);
  DisplayLine(graw.eMessage,Format('Message %d is %d bytes', [MsgNbr,MsgSize]));
  DisplayLine(graw.eMessage,'Downloading, please wait...');
  Code := seeGetEmailLines(0, MsgNbr, 99999, BufferPtr, BufferSize-1);
  If Code < 0 then
    begin
      DisplayLine(eMessage, 'seeGetEmailLines: ');
      DisplayError(eMessage, Code);
      mCheckmail.Enabled := True;
      SCREEN.Cursor := crDefault;
      seeClose(0);
      seeRelease;
      exit;
    end;
  {save message to disk as file FILE.RAW}
  Text := StrPas(BufferPtr);
  AssignFile(FileP,'FILE.RAW');
  ReWrite(FileP);
  Write(FileP, Text);
  CloseFile(FileP);
    DisplayLine(graw.eMessage,'Download compete.');
  {all done}
  SCREEN.Cursor := crDefault;
  mCheckmail.Enabled := True;
  FreeMem(BufferPtr,BufferSize);
  FreeMem(TempPtr,TempSize);
  seeClose(0);
  seeRelease;
end;

end.
