{
  SEEW.PAS:Wrapper for SEE.PAS

  The functions in this unit call the functions in the SEE.PAS unit.
  Note that normal Delphi strings are passed to all functions in this
  unit,  rather than PChar pointers,  as in the SEE.PAS unit. Also note
  that Delphi 1 (unlike later versions) is limited to 255 byte strings.
  Therefore, use this unit with DELPHI 2 and above ONLY.

  See example programs HELO and AUTO, which use this unit.
}

unit seew;

interface

uses see,  SysUtils;

function fAttach(seeNbrChans:Integer; seeKeyCode:LongInt):Integer;
function fClose(seeChan:Integer):Integer;
function fCommand(seeChan:Integer; seeText:String):Integer;
function fDebug(seeChan:Integer; seeIndex:Integer; var seeBuffer:String):Integer;
function fDecodeBuffer(seeCodedBuf:String; var seeClearBuf:String):Integer;
function fDeleteEmail(seeChan:Integer; seeMsgNbr:Integer):Integer;
function fDriver(seeChan:Integer):Integer;
function fEncodeBuffer(seeClearBuf:String; var seeCodedBuf:String):Integer;
function fErrorText(seeChan:Integer; seeCode:Integer; var seeBuffer:String):Integer;
function fExtractLine(seeSource:String; seeLineNbr:Integer; var seeBuffer:String):Integer;
function fExtractText(seeSource, seeText:String; var seeBuffer:String):Integer;
function fGetEmailCount(seeChan:Integer):Integer;
function fGetEmailFile(seeChan:Integer; seeMsgNbr:Integer; seeFileName, seeEmailDir, seeAttachDir:String):Integer;
function fGetEmailLines(seeChan:Integer; seeMsgNbr, seeLines:Integer; var seeBuffer:String):Integer;
function fGetEmailSize(seeChan:Integer; seeMsgNbr:Integer):LongInt;
function fGetEmailUID(seeChan:Integer; seeMsgNbr:Integer; var seeBuffer:String):Integer;
function fIntegerParam(seeChan:Integer; seeIndex:Integer; seeValue:LongInt):Integer;
function fPop3Connect(seeChan:Integer; seeServer, seeUser, seePass:String):Integer;
function fRelease:Integer;
function fSendEmail(seeChan:Integer; seeRcpt, seeCC, seeBCC, seeSubj, seeMsg, seeAttach:String):Integer;
function fSmtpConnect(seeChan:Integer; seeServer, seeFrom, seeReply:String):Integer;
function fStatistics(seeChan:Integer; seeIndex:Integer):Integer;
function fStringParam(seeChan:Integer; seeParamName:Integer; seeParamString:String):Integer;
function fVerifyFormat(seeEmailAddr:String):Integer;
function fVerifyUser(seeChan:Integer; seeEmailAddr:String):Integer;

implementation

function fAttach(seeNbrChans:Integer; seeKeyCode:LongInt):Integer;
begin
  fAttach := seeAttach(seeNbrChans, seeKeyCode)
end;

function fClose(seeChan:Integer):Integer;
begin
  fClose := seeClose(seeChan)
end;

function fCommand(seeChan:Integer; seeText:String):Integer;
var
  Code      : Integer;
  StringLen : Integer;
  StringPtr : PChar;
begin
  {allocate memory}
  StringLen := Length(seeText)+1;
  GetMem(StringPtr,  StringLen);
  StrPCopy(StringPtr,  seeText);
  {make the call}
  Code := seeCommand(seeChan,  StringPtr);
  {free memory}
  FreeMem(StringPtr,  StringLen);
  {return result}
  fCommand := Code
end;

function fDebug(seeChan:Integer; seeIndex:Integer; var seeBuffer:String):Integer;
var
  Code      : Integer;
  BufferLen : Integer;
  BufferPtr : PChar;
begin
  {allocate memory}
  BufferLen := 128;
  GetMem(BufferPtr,  BufferLen);
  {make the call}
  Code := seeDebug(seeChan,  seeIndex,  BufferPtr,  BufferLen);
  seeBuffer := StrPas(BufferPtr);
  {free memory}
  FreeMem(BufferPtr,  BufferLen);
  {return result}
  fDebug := Code
end;

function fDecodeBuffer(seeCodedBuf:String; var seeClearBuf:String):Integer;
var
  Code        : Integer;
  CodedBufLen : Integer;
  ClearBufLen : Integer;
  CodedBufPtr : PChar;
  ClearBufPtr : PChar;
begin
  {allocate memory for seeCodedBuf}
  CodedBufLen := Length(seeCodedBuf)+1;
  GetMem(CodedBufPtr,  CodedBufLen);
  StrPCopy(CodedBufPtr,  seeCodedBuf);
  {allocate memory for seeClearBuf}
  ClearBufLen := 512;
  GetMem(ClearBufPtr,  ClearBufLen);
  {make the call}
  Code := seeDecodeBuffer(CodedBufPtr, ClearBufPtr, ClearBufLen);
  seeClearBuf := StrPas(ClearBufPtr);
  {free memory}
  FreeMem(CodedBufPtr, CodedBufLen);
  FreeMem(ClearBufPtr, ClearBufLen);
  {return result}
  fDecodeBuffer := Code
end;

function fDeleteEmail(seeChan:Integer; seeMsgNbr:Integer):Integer;
begin
  fDeleteEmail := seeDeleteEmail(seeChan, seeMsgNbr)
end;

function fDriver(seeChan:Integer):Integer;
begin
  fDriver := seeDriver(seeChan)
end;

function fEncodeBuffer(seeClearBuf:String; var seeCodedBuf:String):Integer;
var
  Code        : Integer;
  CodedBufLen : Integer;
  ClearBufLen : Integer;
  CodedBufPtr : PChar;
  ClearBufPtr : PChar;
begin
  {allocate memory for seeClearBuf}
  ClearBufLen := Length(seeClearBuf)+1;
  GetMem(ClearBufPtr,  ClearBufLen);
  StrPCopy(ClearBufPtr,  seeClearBuf);
  {allocate memory for seeCodedBuf}
  CodedBufLen := 128;
  GetMem(CodedBufPtr,  CodedBufLen);
  {make the call}
  Code := seeEncodeBuffer(ClearBufPtr, CodedBufPtr, CodedBufLen);
  seeCodedBuf := StrPas(CodedBufPtr);
  {free memory}
  FreeMem(CodedBufPtr,  CodedBufLen);
  FreeMem(ClearBufPtr,  ClearBufLen);
  {return result}
  fEncodeBuffer := Code
end;

function fErrorText(seeChan:Integer; seeCode:Integer; var seeBuffer:String):Integer;
var
  Code      : Integer;
  BufferLen : Integer;
  BufferPtr : PChar;
begin
  {allocate memory}
  BufferLen := 128;
  GetMem(BufferPtr,  BufferLen);
  {make the call}
  Code := seeErrorText(seeChan,  seeCode,  BufferPtr,  BufferLen);
  seeBuffer := StrPas(BufferPtr);
  {free memory}
  FreeMem(BufferPtr,  BufferLen);
  {return result}
  fErrorText := Code
end;

function fExtractLine(seeSource:String; seeLineNbr:Integer; var seeBuffer:String):Integer;
var
  Code      : Integer;
  SourceLen : Integer;
  BufferLen : Integer;
  SourcePtr : PChar;
  BufferPtr : PChar;
begin
  {allocate memory for seeSource}
  SourceLen := Length(seeSource)+1;
  GetMem(SourcePtr,  SourceLen);
  StrPCopy(SourcePtr,  seeSource);
  {allocate memory for seeBuffer}
  BufferLen := 128;
  GetMem(BufferPtr,  BufferLen);
  {make the call}
  Code := seeExtractLine(SourcePtr,seeLineNbr,BufferPtr,BufferLen);
  seeBuffer := StrPas(BufferPtr);
  {free memory}
  FreeMem(SourcePtr,  SourceLen);
  FreeMem(BufferPtr,  BufferLen);
  {return result}
  fExtractLine := Code
end;

function fExtractText(seeSource, seeText:String; var seeBuffer:String):Integer;
var
  Code      : Integer;
  SourceLen : Integer;
  TextLen   : Integer;
  BufferLen : Integer;
  SourcePtr : PChar;
  TextPtr   : PChar;
  BufferPtr : PChar;
begin
  {allocate memory for seeSource}
  SourceLen := Length(seeSource)+1;
  GetMem(SourcePtr,  SourceLen);
  StrPCopy(SourcePtr,  seeSource);
  {allocate memory for seeText}
  TextLen := Length(seeText)+1;
  GetMem(TextPtr,  TextLen);
  StrPCopy(TextPtr,  seeText);
  {allocate memory for seeBuffer}
  BufferLen := 128;
  GetMem(BufferPtr,  BufferLen);
  {make the call}
  Code := seeExtractText(SourcePtr, TextPtr, BufferPtr, BufferLen);
  seeBuffer := StrPas(BufferPtr);
  {free memory}
  FreeMem(SourcePtr,  SourceLen);
  FreeMem(TextPtr,  TextLen);
  FreeMem(BufferPtr,  BufferLen);
  {return result}
  fExtractText := Code
end;

function fGetEmailCount(seeChan:Integer):Integer;
begin
   fGetEmailCount := seeGetEmailCount(seeChan)
end;

function fGetEmailFile(seeChan:Integer; seeMsgNbr:Integer; seeFileName, seeEmailDir, seeAttachDir:String):Integer;
var
  Code         : Integer;
  FileNameLen  : Integer;
  EmailDirLen  : Integer;
  AttachDirLen : Integer;
  FileNamePtr  : PChar;
  EmailDirPtr  : PChar;
  AttachDirPtr : PChar;
begin
  {allocate memory for seeFileName}
  FileNameLen := Length(seeFileName)+1;
  GetMem(FileNamePtr,  FileNameLen);
  StrPCopy(FileNamePtr,  seeFileName);
  {allocate memory for seeEmailDir}
  EmailDirLen := Length(seeEmailDir)+1;
  GetMem(EmailDirPtr,  EmailDirLen);
  StrPCopy(EmailDirPtr,  seeEmailDir);
  {allocate memory for seeAttachDir}
  AttachDirLen := Length(seeAttachDir)+1;
  GetMem(AttachDirPtr,  AttachDirLen);
  StrPCopy(AttachDirPtr,  seeAttachDir);
  {make the call}
  Code := seeGetEmailFile(seeChan, seeMsgNbr, FileNamePtr, EmailDirPtr, AttachDirPtr);
  {free memory}
  FreeMem(FileNamePtr,  FileNameLen);
  FreeMem(EmailDirPtr,  EmailDirLen);
  FreeMem(AttachDirPtr, AttachDirLen);
  {return result}
  fGetEmailFile := Code
end;

function fGetEmailLines(seeChan:Integer; seeMsgNbr, seeLines:Integer; var seeBuffer:String):Integer;
var
  Code      : Integer;
  BufferLen : Integer;
  BufferPtr : PChar;
begin
  {allocate memory for seeBuffer}
  BufferLen := 5000;
  GetMem(BufferPtr,  BufferLen);
  {make the call}
  Code := seeGetEmailLines(seeChan, seeMsgNbr, seeLines, BufferPtr, BufferLen);
  seeBuffer := StrPas(BufferPtr);
  {free memory}
  FreeMem(BufferPtr,  BufferLen);
  {return result}
  fGetEmailLines := Code
end;

function fGetEmailSize(seeChan:Integer; seeMsgNbr:Integer):LongInt;
begin
  fGetEmailSize := seeGetEmailSize(seeChan, seeMsgNbr)
end;

function fGetEmailUID(seeChan:Integer; seeMsgNbr:Integer; var seeBuffer:String):Integer;
var
  Code      : Integer;
  BufferLen : Integer;
  BufferPtr : PChar;
begin
  {allocate memory for seeBuffer}
  BufferLen := 128;
  GetMem(BufferPtr,  BufferLen);
  {make the call}
  Code := seeGetEmailUID(seeChan, seeMsgNbr, BufferPtr, BufferLen);
  seeBuffer := StrPas(BufferPtr);
  {free memory}
  FreeMem(BufferPtr,  BufferLen);
  {return result}
  fGetEmailUID := Code
end;

function fIntegerParam(seeChan:Integer; seeIndex:Integer; seeValue:LongInt):Integer;
begin
  fIntegerParam := seeIntegerParam(seeChan, seeIndex, seeValue)
end;

function fPop3Connect(seeChan:Integer; seeServer, seeUser, seePass:String):Integer;
var
  Code    : Integer;
  HostLen : Integer;
  HostPtr : PChar;
  UserLen : Integer;
  UserPtr : PChar;
  PassLen : Integer;
  PassPtr : PChar;
begin
  {allocate memory for seeServer}
  HostLen := Length(seeServer)+1;
  GetMem(HostPtr,  HostLen);
  StrPCopy(HostPtr,  seeServer);
  {allocate memory for seeUser}
  UserLen := Length(seeUser)+1;
  GetMem(UserPtr,  UserLen);
  StrPCopy(UserPtr,  seeUser);
  {allocate memory for seePass}
  PassLen := Length(seePass)+1;
  GetMem(PassPtr,  PassLen);
  StrPCopy(PassPtr,  seePass);
  {make the call}
  Code := seePop3Connect(seeChan,  HostPtr,  UserPtr,  PassPtr);
  {free memory}
  FreeMem(HostPtr,  HostLen);
  FreeMem(UserPtr,  UserLen);
  FreeMem(PassPtr,  PassLen);
  {return result}
  fPop3Connect := Code
end;

function fRelease:Integer;
begin
  fRelease := seeRelease
end;

function fSendEmail(seeChan:Integer; seeRcpt, seeCC, seeBCC, seeSubj, seeMsg, seeAttach:String):Integer;
var
  Code      : Integer;
  RcptLen   : Integer;
  CCLen     : Integer;
  BCCLen    : Integer;
  SubjLen   : Integer;
  MsgLen    : Integer;
  AttachLen : Integer;
  RcptPtr   : PChar;
  CCPtr     : PChar;
  BCCPtr    : PChar;
  SubjPtr   : PChar;
  MsgPtr    : PChar;
  AttachPtr : PChar;
begin
  {allocate memory for seeRcpt}
  RcptLen := Length(seeRcpt)+1;
  GetMem(RcptPtr,  RcptLen);
  StrPCopy(RcptPtr,  seeRcpt);
  {allocate memory for seeCC}
  CCLen := Length(seeCC)+1;
  GetMem(CCPtr,  CCLen);
  StrPCopy(CCPtr,  seeCC);
  {allocate memory for seeBCC}
  BCCLen := Length(seeBCC)+1;
  GetMem(BCCPtr,  BCCLen);
  StrPCopy(BCCPtr,  seeBCC);
  {allocate memory for seeSubj}
  SubjLen := Length(seeSubj)+1;
  GetMem(SubjPtr,  SubjLen);
  StrPCopy(SubjPtr,  seeSubj);
  {allocate memory for seeMsg}
  MsgLen := Length(seeMsg)+1;
  GetMem(MsgPtr,  MsgLen);
  StrPCopy(MsgPtr,  seeMsg);
  {allocate memory for seeAttach}
  AttachLen := Length(seeAttach)+1;
  GetMem(AttachPtr,  AttachLen);
  StrPCopy(AttachPtr,  seeAttach);
  {make the call}
  Code := seeSendEmail(seeChan, RcptPtr, CCPtr, BCCPtr, SubjPtr, MsgPtr, AttachPtr);
  {free memory}
  FreeMem(RcptPtr,  RcptLen);
  FreeMem(CCPtr,  CCLen);
  FreeMem(BCCPtr, BCCLen);
  FreeMem(SubjPtr, SubjLen);
  FreeMem(MsgPtr,  MsgLen);
  FreeMem(AttachPtr,  AttachLen);
  {return result}
  fSendEmail := Code
end;

function fSmtpConnect(seeChan:Integer; seeServer, seeFrom, seeReply:String):Integer;
var
  Code      : Integer;
  ServerLen : Integer;
  FromLen   : Integer;
  ReplyLen  : Integer;
  ServerPtr : PChar;
  FromPtr   : PChar;
  ReplyPtr  : PChar;
begin
  {allocate memory for seeServer}
  ServerLen := Length(seeServer)+1;
  GetMem(ServerPtr,  ServerLen);
  StrPCopy(ServerPtr,  seeServer);
  {allocate memory for seeFrom}
  FromLen := Length(seeFrom)+1;
  GetMem(FromPtr,  FromLen);
  StrPCopy(FromPtr,  seeFrom);
  {allocate memory for seeReply}
  ReplyLen := Length(seeReply)+1;
  GetMem(ReplyPtr,  ReplyLen);
  StrPCopy(ReplyPtr,  seeReply);
  {make the call}
  Code := seeSmtpConnect(seeChan, ServerPtr, FromPtr, ReplyPtr);
  {free memory}
  FreeMem(ServerPtr,  ServerLen);
  FreeMem(FromPtr,  FromLen);
  FreeMem(ReplyPtr, ReplyLen);
  {return result}
  fSmtpConnect := Code
end;

function fStatistics(seeChan:Integer; seeIndex:Integer):Integer;
begin
  fStatistics := seeStatistics(seeChan, seeIndex)
end;

function fStringParam(seeChan:Integer; seeParamName:Integer; seeParamString:String):Integer;
var
  Code      : Integer;
  StringLen : Integer;
  StringPtr : PChar;
begin
  {allocate memory}
  StringLen := Length(seeParamString)+1;
  GetMem(StringPtr,  StringLen);
  StrPCopy(StringPtr,  seeParamString);
  {make the call}
  Code := seeStringParam(seeChan,  seeParamName,  StringPtr);
  {free memory}
  FreeMem(StringPtr,  StringLen);
  {return result}
  fStringParam := Code
end;

function fVerifyFormat(seeEmailAddr:String):Integer;
var
  Code         : Integer;
  EmailAddrLen : Integer;
  EmailAddrPtr : PChar;
begin
  {allocate memory for seeEmailAddr}
  EmailAddrLen := Length(seeEmailAddr)+1;
  GetMem(EmailAddrPtr,  EmailAddrLen);
  StrPCopy(EmailAddrPtr,  seeEmailAddr);
  {make the call}
  Code := seeVerifyFormat(EmailAddrPtr);
  {free memory}
  FreeMem(EmailAddrPtr,  EmailAddrLen);
  {return result}
  fVerifyFormat := Code
end;

function fVerifyUser(seeChan:Integer; seeEmailAddr:String):Integer;
var
  Code         : Integer;
  EmailAddrLen : Integer;
  EmailAddrPtr : PChar;
begin
  {allocate memory for seeEmailAddr}
  EmailAddrLen := Length(seeEmailAddr)+1;
  GetMem(EmailAddrPtr,  EmailAddrLen);
  StrPCopy(EmailAddrPtr,  seeEmailAddr);
  {make the call}
  Code := seeVerifyUser(seeChan, EmailAddrPtr);
  {free memory}
  FreeMem(EmailAddrPtr,  EmailAddrLen);
  {return result}
  fVerifyUser := Code
end;

(* initialization *)
begin
end.
